@@ -11,7 +11,9 @@ use core::{
         ShlAssign, Shr, ShrAssign, Sub,
     },
 };
+
 use num_traits::{Bounded, Num, One, Zero};
+use serde::{Deserializer, Serializer};
 
 /// [UnsafeStorage] is used to mark that there are some arbitrary invariants
 /// which must be maintained in storing its inner value. Therefore, creation and
@@ -129,6 +131,25 @@ macro_rules! new_signed_types {
 
         always_valid!($name);
 
+        impl serde::Serialize for $name {
+            fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error>
+            where
+                S: Serializer,
+            {
+                self.value().serialize(serializer)
+            }
+        }
+
+        impl serde::Deserialize<'static> for $name {
+            fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>
+            where
+                D: Deserializer<'static>,
+            {
+                let inner = <$signed>::deserialize(deserializer)?;
+                $name::new(inner).ok_or(serde::de::Error::custom("invalid size"))
+            }
+        }
+
         impl PartialOrd for $name {
             fn partial_cmp(&self, other: &Self) -> Option<Ordering> {
                 self.value().partial_cmp(&other.value())
@@ -406,6 +427,25 @@ macro_rules! new_unsigned_types {
             }
         }
 
+        impl serde::Serialize for $name {
+            fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error>
+            where
+                S: Serializer,
+            {
+                self.value().serialize(serializer)
+            }
+        }
+
+        impl serde::Deserialize<'static> for $name {
+            fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>
+            where
+                D: Deserializer<'static>,
+            {
+                let inner = <$inner>::deserialize(deserializer)?;
+                $name::new(inner).ok_or(serde::de::Error::custom("invalid size"))
+            }
+        }
+
         #[macro_export]
         macro_rules! $name {
             ($value: literal) => {
